@@ -109,6 +109,7 @@ AttributeTableEntry attributeTable[] = {
     { "LogAnisoAppControlled", NV_CTRL_LOG_ANISO_APPLICATION_CONTROLLED,0 },
     { "RefreshRate",           NV_CTRL_REFRESH_RATE,                N|H   },
     { "InitialPixmapPlacement",NV_CTRL_INITIAL_PIXMAP_PLACEMENT,    N     },
+    { "GlyphCache",            NV_CTRL_GLYPH_CACHE,                 N     },
     { "PCIBus",                NV_CTRL_PCI_BUS,                     N     },
     { "PCIDevice",             NV_CTRL_PCI_DEVICE,                  N     },
     { "PCIFunc",               NV_CTRL_PCI_FUNCTION,                N     },
@@ -208,6 +209,7 @@ AttributeTableEntry attributeTable[] = {
     { "GPU2DClockFreqs",        NV_CTRL_GPU_2D_CLOCK_FREQS,         N|P },
     { "GPU3DClockFreqs",        NV_CTRL_GPU_3D_CLOCK_FREQS,         N|P },
     { "GPUCurrentClockFreqs",   NV_CTRL_GPU_CURRENT_CLOCK_FREQS,    N|P },
+    { "GPUPerfModes",           NV_CTRL_STRING_PERFORMANCE_MODES,   S|N },
 
     { "NvidiaDriverVersion",    NV_CTRL_STRING_NVIDIA_DRIVER_VERSION,    S|N },
     { "NvControlVersion",       NV_CTRL_STRING_NV_CONTROL_VERSION,       S|N },
